@@ -45,10 +45,12 @@
        ;; Ensure required slots are filled.
        (and (memq #:required? options)
             (or (member keyword initargs)
-                (error (format #f
-                               "~a: Required field `~a' missing.~%"
-                               (class-name klass)
-                               (slot-definition-name slot)))))
+                (raise (condition
+                        (&gwl-error)
+                        (&formatted-message
+                         (format "~a: required field `~a' missing.~%")
+                         (arguments (list (class-name klass)
+                                          (slot-definition-name slot))))))))
 
        ;; Only perform these checks if a value is provided.
        (and=> (member keyword initargs)
@@ -85,10 +87,12 @@
                      ((_ value . rest)
                       ;; TODO: allow for better error messages
                       (or (validate value)
-                          (error (format #f
-                                         "~a: field `~a' has the wrong type.~%"
-                                         (class-name klass)
-                                         (slot-definition-name slot)))))))
+                          (raise (condition
+                                  (&gwl-error)
+                                  (&formatted-message
+                                   (format "~a: field `~a' has the wrong type.~%")
+                                   (arguments (list (class-name klass)
+                                                    (slot-definition-name slot))))))))))
                   (_ #t))))))
    (class-slots klass))
 
