@@ -1,5 +1,5 @@
 ;;; Copyright © 2017, 2018 Roel Janssen <roel@gnu.org>
-;;; Copyright © 2018, 2019, 2020, 2021 Ricardo Wurmus <rekado@elephly.net>
+;;; Copyright © 2018, 2019, 2020, 2021, 2022 Ricardo Wurmus <rekado@elephly.net>
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify it
 ;;; under the terms of the GNU General Public License as published by
@@ -24,8 +24,10 @@
   #:use-module ((guix profiles)
                 #:select
                 (profile
+                 manifest manifest?
                  manifest-search-paths
-                 packages->manifest))
+                 packages->manifest
+                 concatenate-manifests))
   #:use-module ((guix search-paths)
                 #:select
                 (search-path-specification->sexp))
@@ -38,6 +40,7 @@
   #:use-module (srfi srfi-26)
   #:use-module (srfi srfi-34)
   #:use-module (srfi srfi-35)
+  #:use-module (srfi srfi-71)
   #:use-module (ice-9 threads)
   #:use-module (ice-9 rdelim)
   #:export (make-process
@@ -53,6 +56,7 @@
             process-synopsis
             process-description
 
+            process-manifest
             process-outputs
             process-output-path
             process-takes-available
@@ -184,27 +188,33 @@
   (packages
    #:accessor process-packages
    #:init-keyword #:packages
-   #:init-value '()
+   #:init-form (manifest '())
    #:implicit-list? #t
-   #:validator (lambda (value)
-                 (every valid-package? value))
+   #:validator manifest?
    #:transformer
    ;; TODO: the instance name is not be available at this point, so we
    ;; can't report the process name here.  We should move the
    ;; transformers and validators to a point after initialization.
-   (lambda (instance value)
-     (map (match-lambda
-            ((and (? string?) spec)
-             (lookup-package spec))
-            ((and (? valid-package?) pkg)
-             pkg)
-            (x
-             (raise
-              (condition
-               (&gwl-type-error
-                (expected-type (list "<package>" "<inferior-package>" "<string>"))
-                (actual-value x))))))
-          value)))
+   (match-lambda*
+     ((_ (? manifest? value)) value)
+     ((_ packages)
+      (packages->manifest
+       (map
+        (match-lambda
+          ((? string? spec)
+           (let ((pkg out (lookup-package spec)))
+             (list pkg out)))
+          ((? valid-package? pkg)
+           pkg)
+          (((? valid-package? pkg) (? string? out))
+           (list pkg out))
+          (x
+           (raise
+            (condition
+             (&gwl-type-error
+              (expected-type (list "<package>" "<inferior-package>" "<string>"))
+              (actual-value x))))))
+        packages)))))
   (inputs
    #:accessor process-raw-inputs
    #:init-keyword #:inputs
@@ -640,6 +650,13 @@ tags if WITH-TAGS? is #FALSE or missing."
         (map mangle (process-outputs* proc))
         (map mangle (remove keyword? (process-outputs* proc))))))
 
+(define (process-manifest process)
+  (concatenate-manifests
+   ;; Put process packages before bash-minimal, so that
+   ;; they're not shadowed.
+   (list (process-packages process)
+         (packages->manifest (list (bash-minimal))))))
+
 (define (process-takes-available process)
   "Returns #T when the data inputs of the PROCESS exist."
   (match (process-inputs process)
@@ -686,12 +703,7 @@ tags if WITH-TAGS? is #FALSE or missing."
   "Return a lowerable object for the script that will execute the
 PROCESS."
   (let* ((name         (process-full-name process))
-         (packages     (cons (bash-minimal)
-                             (process-packages process)))
-         (manifest     (packages->manifest (map
-                                            (lambda (pkg)
-                                              (list pkg (package-output pkg)))
-                                            packages)))
+         (manifest     (process-manifest process))
          (profile      (profile (content manifest)))
          (search-paths (delete-duplicates
                         (map search-path-specification->sexp
@@ -700,12 +712,10 @@ PROCESS."
          (exp
           (with-imported-modules (source-module-closure (script-modules))
             #~(begin
-                #$@(if (null? packages) '()
-                       `((use-modules (guix search-paths))
-                         (set-search-paths (map sexp->search-path-specification
-                                                ',search-paths)
-                                           (cons ,profile
-                                                 ',packages))))
+                (use-modules (guix search-paths))
+                (set-search-paths (map sexp->search-path-specification
+                                       '#$search-paths)
+                                  (list #$profile))
                 #$(if out `(setenv "out" ,out) "")
                 (setenv "_GWL_PROFILE" #$profile)
                 (use-modules (ice-9 match))
@@ -728,7 +738,7 @@ PROCESS."
 (define* (process->script-wrapper process
                                   #:key make-wrapper workflow scripts-table)
   (make-wrapper process
-                (hash-ref scripts-table process)
+                (hashq-ref scripts-table process)
                 #:workflow workflow
                 #:scripts-table scripts-table))
 
