@@ -17,6 +17,7 @@
 (define-module (gwl workflows graph)
   #:use-module (ice-9 format)
   #:use-module (ice-9 match)
+  #:use-module (guix profiles)
   #:use-module (gwl packages)
   #:use-module (gwl processes)
   #:use-module (gwl workflows)
@@ -46,7 +47,7 @@ label=<<FONT POINT-SIZE=\"14\">~a</FONT><BR/>\
             (match (process-packages process)
               (() "")
               (inputs (format #f "<BR/>Uses: ~{~a~^, ~}."
-                              (map package-name inputs)))))))
+                              (map manifest-entry-name inputs)))))))
 
 (define (workflow-restriction->dot process . restrictions)
   "Write the dependency relationships of a restriction in dot format."
