@@ -1,4 +1,5 @@
 ;;; Copyright © 2016, 2017  Roel Janssen <roel@gnu.org>
+;;; Copyright © 2021 Ricardo Wurmus <rekado@elephly.net>
 ;;;
 ;;; This program is free software: you can redistribute it and/or
 ;;; modify it under the terms of the GNU Affero General Public License
@@ -20,7 +21,14 @@
 
 (define (page-community request-path)
   (page-root-template "Guix Workflow Language" request-path
-   `((h2 "Community")
-     (p "Please interact with us through the "
-        (a (@ (href "https://lists.gnu.org/mailman/listinfo/gwl-devel"))
-           "mailing list") "."))))
+   `((h1 "Get in Touch!")
+     (p "For real-time support from the community, you can connect to
+the " (code "#guix-hpc") " channel on irc.freenode.net.  There you can
+get help about anything related to GNU Guix and the Guix Workflow
+Language in an HPC context.
+
+The " (code "#guix-hpc") " channel is logged. Previous conversations
+can be browsed online. See the "
+(a (@ (href "https://logs.guix.gnu.org/guix-hpc")) "channel logs") ".")
+     (p "Long-form discussions are best held on the " (a (@ (href "mailto:gwl-devel@gnu.org")) "mailing list") ".")
+     (p "You can " (a (@ (href "https://lists.gnu.org/mailman/listinfo/gwl-devel")) "browse the list archives here") "."))))
