@@ -1,5 +1,5 @@
 ;;; Copyright © 2018 Roel Janssen <roel@gnu.org>
-;;; Copyright © 2019, 2020, 2021 Ricardo Wurmus <rekado@elephly.net>
+;;; Copyright © 2019, 2020, 2021, 2022 Ricardo Wurmus <rekado@elephly.net>
 ;;;
 ;;; This program is free software: you can redistribute it and/or
 ;;; modify it under the terms of the GNU Affero General Public License
@@ -35,6 +35,9 @@
         " have been installed already.  In case the GNU GWL hasn't been"
         " installed, run: " (code "guix install gwl"))
 
+     (p "Then tell Guix where to find the GWL extension: "
+        (code "export GUIX_EXTENSIONS_PATH=$HOME/.guix-profile/share/guix/extensions"))
+
      (h2 "Introduction")
 
      (p "In the GWL there are two concepts we need to know
