@@ -317,4 +317,45 @@ make-workflow
     (equal? '(this and that whatever you say)
             (process-inputs proc))))
 
+(define top-srcdir (getenv "abs_top_srcdir"))
+(define (abs-example example)
+  (canonicalize-path
+   (string-append top-srcdir "/doc/examples/" example)))
+
+(test-equal "workflow-files: lists itself"
+  (map abs-example
+       (list "haiku.w"))
+  (workflow-files
+   (abs-example "haiku.w")))
+
+(test-equal "workflow-files: lists referenced workflows"
+  (map abs-example
+       (list "haiku.w"
+             "simple-wisp.w"
+             "include-test.w"))
+  (workflow-files
+   (abs-example "include-test.w")))
+
+(test-equal "workflow-files: lists referenced workflows"
+  (map abs-example
+       (list "example-workflow.w"
+             "haiku.w"
+             "simple-wisp.w"
+             "include-test.w"
+             "include-test2.w"))
+  (workflow-files
+   (abs-example "include-test2.w")))
+
+(test-equal "workflow-hash: ignores whitespace changes"
+  (workflow-hash
+   (abs-example "include-test2.w"))
+  (workflow-hash
+   (abs-example "include-test3.w")))
+
+(test-assert "workflow-hash: does not ignore actual changes"
+  (not (equal? (workflow-hash
+                (abs-example "include-test.w"))
+               (workflow-hash
+                (abs-example "include-test2.w")))))
+
 (test-end "workflows")
